# Changelog

All notable changes to the RSS2I project will be documented in this file.

## [Unreleased]

### Changed

  - [rss2ipy](python/rss2ipy) python module: Load the shared library by
    availability using a try-and-error approach. (7fcb526)
    
  - The timers within the [timer module](src/timer.c) are now checked
    asynchronously. This improves the stability of the firmware significantly.
    (4ed39c2)
    
  - [Makefile](Makefile) targets `tests` and `runtests`: Rename the old targets
    `test` and `runtest` to `tests` and `runtests`, respectively. (5519bab)
  
  - The measured RSS values are now rounded properly by the
    [radio module](src/radio.c). (82f3298)
  
  - The [Makefile](Makefile) target `all` is replaced by `librss2i` since
    it was decided to have just a single shared library that bundles the
    functionality, which is used by the [rss2ipy python package](pthon/rss2ipy).
    (2fcd8d3)
    
  - The RSS measurement accuracy was optimized by enhancing the number of RSSI
    samplings per measurement packet significantly. (bb7b1d3)
  
  - Replaced matplotlib by pyqt5 and pyqtgraph as frontend for the real-time
    graphs. This results in much faster and smoother operation.
    (241b565, e21b150)
  
  - The [nrf5lib](https://git.uni-wuppertal.de/rss2i/nrf5lib) is replaced by a
    patched [libopencm3](https://git.uni-wuppertal.de/rss2i/libopencm3). This
    dependency is now a git submodule. (1337284, e93d61c, 7ef01e2, f8ed74f)
  
  - Firmware: The debug log repetion delay is now controlled by the
    [timer module](src/timer.c). (ba7b212)
    
  - Firmware: Changed the USB live log behaviour so that the log functionality
    is available even for rather large measurement configurations, i.e.
    `measureFrameCount > USB_BUFFER_LENGTH`. (3eb54ad)
  
  - [rss2i.py](rss2i.py): New configuration for the `log` command.
    (9a62bbc, c51aee6, ad99d09)
  
  - [rss2ipy](python/rss2ipy): Added a flag in order to switch between a lax and
    a tight timeout handling. (d80c143)
  
  - The firmware is now built for board revision I by default.
    (479b701, bddcebc, e462faf, ae2902c, 9b47074)
  
  - Measurement results and measurement packet meta data are now stored on the
    measurement buffer using DMA. This reduces CPU load and enables support for
    upcoming BLE 5.1 Direction Finding tasks, i.e. storing samples during the
    BLE 5.1 Constant Tone Extension (CTE). (822ced0, 1daed41, 9f5729f)
  
  - Several blocking delay and computation optimizations using DMA buffering.
    (2b2dbc8, 9954220, c52f10c, d5852f1, 97969f3, 0f908d4)
  
  - Introduced two debug levels with different levels of verbosity. (e4c1caf)
  
  - Switched to C11 standard. (6617678)
  
  - [rss2ipy](python/rss2ipy): Remember `laxTimeout` settings when changing the
    baudrate. (8ed14c8)
  
  - [Makefile](Makefile): (Board) revision and board type values are now
    self-descriptive. One may specify `A` for revision A and `arr` for antenna
    array type and so on. (458eb99)
  
  - Outsourced the livelog functionality from the
    [measurement module](src/measure.c) into the new
    [live log module](src/livelog.c). (866f818, ab64b46)
  
  - #12: [rss2ipy](python/rss2ipy): Rename command names and aliases: `debug`
    becomes `log` and `join` becomes `measure`. (c51aee6, d3be202)
    
  - Fitted the measurement frame timing debug mode to the existence of CTEs and
    their variable lengths. (e3e0ef7, 646bd7c, cd631f9, ab92b81)
  
  - [Measurement module](src/measure.c): Splitted the frame preparation and
    initialization into two separate parts. This reduces the individual
    interrupt durations. (af2129b, 1daed41, 9f5729f)
  
  - The [test firmware](test.c) now uses alternating antennas in a five second
    interval while emitting a constant carrier.
    (6f49799, 74ae31e, a60a3a3, eb2453f, d958f48)
  
  - #11: [rss2i.py](rss2i.py): Change the default behaviour of the
    *Remote RSS input map*: Every frame is now mapped to the virtual memory
    location with the same index by default. (5187b6e, 369858d)
  
  - [Measurement timings](include/rss2i/config/measure.h): Changed the
    measurement frame timings. The measurement frame itself as well as the
    actual packet are still 200 µs and 100 µs long, respectively. But the guard
    interval lengths were reduced in order to have more time for preparation of
    the measurement packet. (0c21bac, 843aa84)
  
  - Some (function) names had to be renamed in order to clean up the namespace.
    (ab64b46)
  
  - Removed `-c` switch from the live `log` subcommand of the
    [rss2i.py tool](rss2i.py). (8f3437d, 0308df7)
    
  - Add a target field to the `0x00` *Tell me who you are*
    [command](src/cmd.c) and fitted the [rss2i.py tool](rss2i.py) to this
    change. (710afbc, 3f66d43)
  
  - The GPIO toggling for debugging the measurement frame timings is now partly
    controlled by [PPI](src/ppi.c) and [GPIOTE](src/gpiote.c). This reduces
    the additional processing load as well as some delays between the GPIO
    toggle and the actual event. Furthermore, this enables much more precise
    measurement frame calibration. (7041d09)
  
  - Redesigned and reimplemented the synchronization between RSS2I devices
    during a measurement. An overview is given in the
    [measurement config file](include/rss2i/config/measure.h). (d6b5eb4)
  
  - Recalibrated the measurement frame timimings. The achievable accuracy is
    better than 0.1 percent with regard to frame length. (d6b5eb4)
  
  - Supported storage of raw RSS or IQ samples onto the external flash memory.
    This coincides with a changed flash layout. Fitted the
    [rss2i.py tool](rss2i.py) to these changes.
    (e4fd41b, 145fc22, 55eb4c6, 07096c1, b6b31b5, cb4beb5, 6daf39e, c510928,
    a5d6eb6, 311cd41, d24ce3d, 6d706d7, ffd7ffb, a0d66b2, 88c6d6a, 0c6cf78,
    0ea33f4, 0e36513, dc8100d, b6ef535)
  
  - Outsourced some common functions of the unit tests into some kind of
    [unit test framework](test/test.c). (9e4b59a, e83dcf3, f70fcfb)
  
  - [rss2ipy](python/rss2ipy): Replace `page_decode` with `memory_decode` that
    supports decoding of a bunch of flash pages that may hold raw (IQ) samples.
    (6d706d7, a0d66b2, 0ea33f4)
  
  - [rss2i.py](rss2i.py): #18: Unify output prefix `-o` switch behaviour and
    rename the output files. (4efb8c0)
  
  - [rss2i.py](rss2i.py): Return a useful exit status. (4647c6c, 488e553)
  
  - `0x13` *Set out-of-sync thresholds*, `0x12` *Set poor-sync thresholds*:
    Change sync threshold encoding. (dc8100d)

### Added

  - [Makefile](Makefile) target `xlibrss2i`: Cross compiles the shared library
    `librss2i` for several target platforms. (7fcb526, 2fcd8d3)
    
  - [rss2i.py](rss2i.py): New `ping` command: Toggles LEDs of a targeted device
    a few times in order to find devices within the measurement setup. (9f6092b)
  
  - Firmware: The [buffer module](src/buffer.c) now supports Direct Memory
    Access (DMA). (bb9e8ee)
  
  - Firmware: Added commands `0x19` *Return device status* and
    `0x1a` *Report error information* in order to be able to retrieve debugging
    and status information from a device without debugging hardware and even
    over the air. The debug mode is not required for this to work.
    (92fc2aa, a174a00, e9c64d8, 3238018)
  
  - [Makefile](Makefile) target `precommit`: Run some precommit tests.
    (d9cdb48, decb922)
  
  - Added support for board revision F and higher.
    (479b701, 0fcb9a6, bddcebc, c334198, e462faf, 0a7d25d, ae2902c, 1daed41,
    9f5729f)
  
  - Added the [systick module](src/systick.c) that provides both milliseconds
    and microsencods since the system's start up. (d5735ad, 55ebace, e9af4b5)
  
  - Added the [scheduler module](src/scheduler.c) that is capable of
    prioritizing timing ciritical tasks. (6617678, 85152a0, dcbcd48)
  
  - Added a brownout detection. This is an important feature for the correct
    handling of the rev. F/G/H/I onboard HF switch. (5735c09, 1aefcd5, 1daed41)
  
  - Added a DMA-based measurement results writing procedure. This is an
    important feature for the storing of measurement results during a BLE 5.1
    CTE. (97969f3, 0f908d4, 1daed41, 9f5729f)
  
  - [Command module](src/cmd.c): Add BLE 5.1 CTE related informations to the
    `0x00` *Tell me who you are* command. (6cf55d3, be4f062)
  
  - Support BLE 5.1 Direction Finding using a Constant Tone Extension (CTE).
    (6c1ee68, 2dddc76, 1fb7b5e, 47e3a82, a4008d2, a2f6432, 108fc7a, 1738b8f,
    15ff803, 8f1aafa, 2e375a2, 00c6096, 4c236ca, c334198, 7ef01e2, fb59b10,
    6c3ed6d, 700f34a, af2129b, 8d387a3, 5e3c1bd, 97eb1a7, 0c21bac, 5b686f4,
    07df056, 534454e, 1aefcd5, f770ec1, 4109643, 1daed41, 9f5729f, 2b98c67,
    843aa84, fbcd3d2, 03c36bd, dcb32aa, 9ec70ec, 1446571, 57c1718, b0d4ff6,
    e4fd41b, 145fc22, 55eb4c6, 33ace22, b6b31b5, cb4beb5, a0d66b2, 88c6d6a,
    0c6cf78, a4f124d, 9f00c6c, 9710329, 8940db2, )
  
  - New [revision module](src/rev.c) that allows to distinguish more clearly
    between chip and board revision. (049598b, c35c669, 0a7d25d, ae2902c)
  
  - New [cte module](src/rev.c) that handles all BLE 5.1 CTE related
    functionality. (1fb7b5e, 47e3a82, a4008d2, a2f6432, 108fc7a, 15ff803,
    8f1aafa, 2e375a2, 97eb1a7, 07df056, a334165, f770ec1, 1daed41, dbac3ab,
    2b98c67, 843aa84, fbcd3d2, 03c36bd, 57c1718, b0d4ff6, 33ace22, 3b56b9e,
    a0d66b2)
    
  - New [cteinfo module](src/cteinfo.c) that stores all informations about
    compatibilities of RSS2I boards and CTE behaviours.
    (a334165, 843aa84, 4bf1c25, dcb32aa, 50f5580, 9ec70ec, a0d66b2)
    
  - [Command module](src/cmd.c): Added `0x17` *Set CTE configuration* command.
    (4c236ca, 6c3ed6d, 56f027a)
    
  - #13: [rss2i.py](rss2i.py): Added a new `debug` command that is worthy its
    name. (10ef6e7, 19e1cd4, c1f6d1c)
    
  - librss2i, [rss2ipy](python/rss2ipy): Added some information about the
    debug module. (10ef6e7, 5edf001, ff69517)
  
  - #15: [rss2i.py](rss2i.py): Add `--csv` switch to enable comma separated
    output. (b6d3614)
  
  - Introduced debug toggle level `3` that enables precise timing analysis
    during a measurement frame. (6b1c59b, cd631f9, ab92b81, 83d7e0c, 7041d09)
  
  - New [switch module](src/switch.c) that controls an external HF switch (if
    any). (8d387a3, 5e3c1bd, 1aefcd5, 394f075, 4109643, 1daed41, 34a83bb,
    eb2453f)
  
  - [Makefile](Makefile) target `size-*`: List section size of the
    specified firmware. (0914f98, 255126b)
    
  - New [postproc module](src/postproc.c) that performs all measurement data
    post processing tasks. (9c6a64f, 4698d44, f13b7fc, a24a1e8, 5b686f4,
    07df056, ab64b46, e4fd41b, c510928, a0d66b2)
  
  - [Command module](src/cmd.c): Add `0x1b` *Collect CTE samples*,
    `0x1c` *Return CTE sample status*, `0x1d` *Clear CTE sample request*,
    `0x1e` *Return CTE sample sheet* and `0x1f` *Return CTE sample sheets*
    commands. (f3fddcd, 9c2eaa8, f01fc99, 5b686f4, 07df056, c077b2d)
  
  - librss2i, [rss2ipy](python/rss2ipy): Add CTE compatibility information.
    (0bfa51a, a4f124d, 9f00c6c, 9710329, 8940db2, )
  
  - [Makefile](Makefile) switch `TOGGLE`: Set debug toggle level. (83d7e0c)
    
  - Added the [errata module](src/errata.c). (a4a9d35)
  
  - Support different radio modes i.e. BLE 2 MBit/1 MBit, Nordic Proprietary
    2 MBit/1 MBit and IEEE 802.15.4. (a4a9d35, 55334e3, 89a43a9, 75bc3b9,
    1446571, 72d85c1, 56f027a, fc15239, 57c1718, b779c12, 33ace22)
  
  - Added a unit test for the [cteinfo module](src/cteinfo.c). (4bf1c25)
  
  - Build whole project when running the tests. (e30d843)
  
  - Added live log byte `0x16` *Local RSS sample amount*. (2140ccd)
  
  - The [rss2i.py utility](rss2i.py) now may dislay information about remote
    devices using the new `-d` switch of the `getid` subcommand.
    (3f66d43, 8abd9d5, 576af6d)
  
  - [Command module](src/cmd.c): Add `0x16` *Set radio mode*. (56f027a)
  
  - New [GPIOTE API module](src/gpiote.c). (5400b74, 7041d09)
  
  - New [NVIC module](src/nvic.c). (e4fbb2b, dea242c)
  
  - Added a unit test for the [systick module](src/systick.c).
    (556eb32, 7149991)
  
  - Added the [const firmware](const.c) that configures the radio to emit a
    so-called constant tone for calibration or measurement purposes. The used
    radio mode, the carrier frequency, the deviation from this carrier frequency
    as well as the used antenna can be set using the corresponding Makefile
    switches. (4d6791b, f6aa39d, 1b7d41a, 47ee69b)
  
  - New [coder module](src/coder.c) that provides some helper routines for
    encoding and decoding flash pages.
    (145fc22, 6daf39e, a5d6eb6, 311cd41, d24ce3d, a0d66b2)
  
  - Added the possibility of appending a specifiable number of zeros to a CRC
    sum to the [CRC module](src/crc.c). (07096c1, 79bee1a)
  
  - [Command module](src/cmd.c): Add `0x18` *Set sample configuration* command.
    (538aa24, 88c6d6a, 0c6cf78)
  
  - librss2i: Add flash memory decoding capabilities. This includes
    functionality for decoding raw (IQ) samples. (d24ce3d)
  
  - [rss2i.py](rss2i.py): Add the `-n` switch to the `record` subcommand.
    (29796e3)
  
### Fixed

  - #1: [rss2i.py](rss2i.py): KeyError when specifying Windows COM port with -p
    switch. (8be065e)
  
  - #2: [rss2i.py](rss2i.py): TypeError when omiting -d switch while parsing
    config file. (071b948)
  
  - #3: [rss2i.py](rss2i.py): Allow 2481 MHz to be a valid frequency. (e42c7b8)
  
  - Deleted misplaced `-flto` from the [Makefile](Makefile)'s `$(CFLAGS)`
    that leads to weird binaries when using some versions of gcc. (1938389)
  
  - Added `-fopenmp` to the [Makefile](Makefile)'s `$(HOSTLDLAGS)`
    in order to fix the `undefined reference` errors during the linking process
    with newer gcc versions. (c496d16)
    
  - #4: [rss2i.py](rss2i.py): Spikes/Outliers in live monitoring. (16e154e)
  
  - Prevent `-Wimplicit-fallthrough` related warnings with newer gcc versions.
    (e5d2fa5)
  
  - Save the synchronization map completely when getting configured. (a7d54d9)
  
  - #6: firmware: Watchdog timeout when trying to download during measurement.
    Downloading measurement data during an ongoing measurement session (via USB)
    is now stable and reliable. (428e30b, 0f908d4, 8ed14c8)
  
  - Fixed the response of the *Return measurement session data* command with
    regard to the number of written flash pages when the memory is full.
    (768e20f)
  
  - #7: [rss2i.py](rss2i.py): ValueError when trying to download from a remote
    device during an ongoing measurement. (162c477)
  
  - [rss2i.py](rss2i.py): Do not ignore the gap parameter within the restore
    command anymore. (8ecdab8)
  
  - Avoid `RADIO_TX_UNPREPARED` errors (see [radio module](src/radio.c)) when a
    poor-sync rule was applied. (c15a9cd)
  
  - Fix timeout handling within [rss2i.py command line tool](rss2i.py) and the
    [rss2ipy python package](python/rss2ipy). (5415ed6, 951e64b, dc9d78b)
  
  - Fix `indexError` while OTA downloading. (8525c72, a27a40d)
  
  - Firmware: Fixed string buffer behaviour when the string to be appended
    exceeds the buffer dimensions. (64d9c9c)
  
  - Firmware: Fix buffer race condition. This race condition could lead to
    hidden entries that could be read from the buffer only after an additional
    write/append request. For buffers withs a length of two this could even lead
    to data loss. (da71312, 1829231)
  
  - Firmware: Fix watchdog timeout when jump on a measurement via USB. (a0ed2b8)
  
  - Handle Ctrl+C and closed plot windows properly within the monitor/livelog
    commands. (0821d98, 0a5ab43, 395542d)
  
  - Fixed the automatic device detection of the [rss2i.py tool](rss2i.py)
    that performed very slow in some situations. (3f106fa)
  
  - Reset the [memory](src/memory.c) properly when starting a new measurement
    session. This prevents corrupted measurement values at the beginning of a
    session in the case the memory has been written completely. (ee069bb)
  
  - #9: Do not mess up the livelog output anymore. (6210d08, 395542d)
  
  - #10: Retry livelog when no packets have been received for some time and
    inform the user about this. (333b773, d80c143, 7d09e74, 395542d)
  
  - [rss2i.py](rss2i.py): Fixed `BrokenPipeError` when piping the output of the
    `log` command to another program. (33d62ba, c51aee6)
    
  - #14: [rss2i.py](rss2i.py): KeyError when running the getid command with
    unknown revision or board type. (0fcb9a6)
  
  - [rss2ipy python package](python/rss2ipy): Stabilized data download in high
    CPU load situations. (3ebf664)
  
  - [timer module](src/timer.c): Fix possible malfunction that may arise
    approximately 50 days after boot. (3c14f46)
  
  - [mlc module](src/mlc.c): The stated `main loop cycles per measurement frame`
    were accidentally multiplied by 10. (5986d46)
  
  - [memory](src/memory.c): Stabilize memory controlling in error case.
    (198d9d4)
  
  - [memory](src/memory.c): Stablize memory test under heavy load. (6cb0181)
  
  - Protect the GPIO pin that is assigned to the measurement frame timing debug
    mode. (646bd7c)
  
  - Minimize the delay between a successfull re-synchronization event and the
    re-start of the measurement schedule manager. This should prevent the debug
    buffer overflow on startup. (bb9b74e, fef76f8, bba9078, d6b5eb4)
  
  - [Control module](src/control.c): Stop distorting commands without target
    field. (b357bfb)
  
  - #16: Need to stop twice after synchronization loss. (078f70a)
  
  - [rss2i.py](rss2i.py): Do not ignore the page amount within the restore
    command anymore when the `-r` switch is specified. (d7451fc)

## [1.1.0] – 2019-07-05

### Changed

  - Allow 2481 MHz to be a valid measurement frequency as it was already stated
    in the user documentation. (fe755cf)

## [1.0.0] – 2019-07-02

Initial public release.

