# RSS2I Code

The RSS2I project aims to provide Bluetooth Low Energy (BLE) based low-cost
sensor devices that are capable of
field strength measurements inside complex mesh network topologies with high
sampling rates and low measurement uncertainties.

This is the RSS2I code project that holds the firmware sources and the
command line tool. The latter may be used to configure and control an RSS2I
device.

## Getting Started

### Installing the RSS2I Command Line Tool

In order to install and run the RSS2I command line tool, a `python3`
installation and a host toolchain is needed. On
[Debian](https://www.debian.org/) based systems (such as
[Ubuntu](https://ubuntu.com/)) this is as easy as running

```sh
apt-get install gcc libc-dev make python3 python3-serial python3-numpy python3-matplotlib
```

with the appropriate rights.
After that, it is necessary to have a look onto the `Important settings`
section of the project's [Makefile](Makefile), in order to fit the binary names
to that ones of the build system (those ones will be probably fine) and to fit
the installation paths
to the desired ones (that is usually the only thing that needs to be done).

Once ready,

```sh
make all
```

will build the necessary shared library and

```sh
make install
```

will install the python script and the corresponding python package into the
system.

### Using the RSS2I Command Line Tool

The [RSS2I documentation repository](https://git.uni-wuppertal.de/rss2i/doc)
provides a user documentation for the command line tool. Since it lacks
a command overview yet, it may be useful to run

```sh
rss2i --help
```

and

```sh
rss2i <command> --help
```

in order to get an overview about the tool. Note, that the used terminal
program must be able to interpret ANSI escape
sequences in order to get well formatted output in some cases.

### Firmware Development

In order to build the firmware, an ARM Cortex-M toolchain is needed as well as a
toolchain for the build host (for creating lookup tables, running unit tests,
etc.).
On [Debian](https://www.debian.org/) based systems these may be installed by
running

```sh
apt-get install gcc-arm-none-eabi libnewlib-arm-none-eabi gcc libc-dev make
```

with the appropriate rights.
Additionally, a copy of the
[nrf5lib](https://git.uni-wuppertal.de/rss2i/nrf5lib) is necessary.

In order to flash an RSS2I board, a Serial Wire Debug (SWD) programmer is
needed, e.g.
[Olimex ARM USB JTAG programmer](https://www.olimex.com/Products/ARM/JTAG/ARM-USB-TINY-H/) +
[Olimex SWD Adapter](https://www.olimex.com/Products/ARM/JTAG/ARM-JTAG-SWD/).
OpenOCD is recommended for flashing. On Debian based systems, running

```sh
apt-get install openocd
```

should be sufficient to install it. Other debugging/programming tools
can be used but will need some changes in the project's [Makefile](Makefile).
The [openocd.cfg](openocd.cfg) file is preconfigured to work with the SWD
programmer
mentioned above. It needs to be fitted to the actual debugging hardware.

After that,
it is necessary to have a look onto the `Important settings`
section of the project's Makefile, in order to fit the binary names to that
one of the build system.

Once ready,

```sh
make <firmware>
```

will build the specified firmware (see below) and/or

```sh
make flash-<firmware>
```

will flash it onto an RSS2I device. Try

```sh
make help
```

in order to get an overview about the firmware development and the build
system.

### Firmware Overview

There are different firmwares available:

* **device**: RSS2I standard firmware. Makes an RSS2I board to be an RSS2I device.
* **test**: Should be used after hardware manufacturing to test the functionality
of the system. The debug UART interface (available via the onboard debug pin header,
activateable via the `DEBUG=1` switch during compilation) provides useful information.
* **parameters**: Programs board-specific parameters (such as the board/device ID)
onto an RSS2I board.
* **memval**: Runs a full memory validation test. The debug UART interface
(mentioned above) provides useful information and progress status.

## Versioning and API

This project uses [SemVer](http://semver.org/) for versioning.
For the versions available, see the tags on this repository.
The documentation of the UART over USB API, which the RSS2I command line tool
relies on, is provided by the
[RSS2I documentation repository](https://git.uni-wuppertal.de/rss2i/doc).

## Authors

* **Gerrit Maus** - *Initial firmware development* -
[Communications Engineering](https://www.bsmk.uni-wuppertal.de/) within the
[School of Electrical, Information and Media Engineering](https://fk6.uni-wuppertal.de/) at the
[University of Wuppertal](https://uni-wuppertal.de) ([funk@maus.xyz](mailto:funk@maus.xyz)).
* **Knut Niemann** - *Initial command line tool development* -
[Communications Engineering](https://www.bsmk.uni-wuppertal.de/) within the
[School of Electrical, Information and Media Engineering](https://fk6.uni-wuppertal.de/) at the
[University of Wuppertal](https://uni-wuppertal.de) ([post@knut-niemann.de](mailto:post@knut-niemann.de)).

## License

This project is licensed under the GNU GPL v3.0+. See the [LICENSE.md](LICENSE.md) file for details.

