/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Set and get board-specific parameters to/from the non-volatile User
  Information Configuration Registers (UICR). Further documentation may be
  found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2018-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2019-04-11    Initial release.
    2019-06-03    Added {BOARD_PARAMS_REV} and {BOARD_PARAMS_TYPE}.
    2019-06-24    Added {BOARD_BATTERY_THRESH}.
    2020-06-04    Introduced {BOARD_TYPE_MAX}.
    2020-06-05    Check for invalid config settings.
    2020-07-14    Check for negative {BOARD_REV}isions.
    2020-07-30    Remove most magic numbers.
    2020-07-30    Use static asserts to check the given {BOARD_*} parameters.
    2020-07-30    Added {board_cte_antennas()}.
    2020-07-30    Distinguish more clearly between board and chip revision.
    2020-07-31    Moved {board_cte_antennas()} to the new cte module.
    2020-08-05    Fix {BOARD_BYTTER_THRESH} typo.
*/

#include <stdint.h>
#include <stdbool.h>

#include <rss2i/rev.h>
#include <rss2i/config/board.h>
#include <rss2i/config/generated.board.h>


#ifdef BOARD_ID
	
	_Static_assert(
		BOARD_ID > 0 && BOARD_ID < BOARD_ID_ALWAYS_LAST_ITEM,
		"Invalid RSS2I board ID specified."
	);
	
#endif
#ifdef BOARD_TYPE
	
	_Static_assert(
		BOARD_TYPE < BOARD_TYPE_ALWAYS_LAST_ITEM,
		"Invalid RSS2I board type specified."
	);
	
#endif
#ifdef BOARD_REV
	
	_Static_assert(
		BOARD_REV >= 0 && BOARD_REV < BOARD_REV_ALWAYS_LAST_ITEM,
		"Invalid RSS2I board revision specified."
	);
	
#endif
#ifdef BOARD_BATTERY_THRESH
	
	_Static_assert(
		BOARD_BATTERY_THRESH < 1024,
		"Invalid RSS2I board battery threshold specified."
	);
	
#endif


uint8_t board_id(void);
uint8_t board_type(void);
uint8_t board_rev(void);
uint16_t board_battery_threshold(void);
bool board_store_params(uint8_t id,
                        uint8_t rev,
                        uint8_t type,
                        uint16_t batteryThresh);
void board_init(void);

