/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Holds some routines for encoding and decoding flash pages. Further
  documentation may be found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2021-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2021-04-02    Initial release.
    2021-04-21    Replace {fmtSpec} with {fmtByte} in {*_increments_*_index()}.
    2021-04-21    Added decoding functionality.
    2021-04-29    Support {CTE_2US_7PX1} {CTEType}.
*/


#include <stdbool.h>

#include <rss2i/postproc.h>


#ifndef RSS2I_INCLUDE_GUARD_CODER_H
#define RSS2I_INCLUDE_GUARD_CODER_H
	
	
	typedef enum {
		
		CODER_FORMAT_BYTE_VALID_RSS_0             = 0,
		CODER_FORMAT_BYTE_VALID_RSS_127           = 127,
		
		CODER_FORMAT_BYTE_COMMAND_NEXT_INDEX,
		CODER_FORMAT_BYTE_COMMAND_NEW_INDEX,
		CODER_FORMAT_BYTE_COMMAND_END_OF_PAGE,
		CODER_FORMAT_BYTE_COMMAND_RESERVED_FIRST,
		CODER_FORMAT_BYTE_COMMAND_RESERVED_LAST   = 137,
		
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_0_SHEET_0 = 138,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_0_SHEET_1,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_0_SHEET_2,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_0_SHEET_3,
		
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_1_SHEET_0 = 148,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_1_SHEET_1,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_1_SHEET_2,
		CODER_FORMAT_BYTE_SAMPLE_FORMAT_1_SHEET_3,
		
	} CoderFormatByte;

	typedef enum {
		
		CODER_FORMAT_SPECIFIER_VALID_RSS       = 127,
		CODER_FORMAT_SPECIFIER_SAMPLE_FORMAT_0 = 138,
		CODER_FORMAT_SPECIFIER_SAMPLE_FORMAT_1 = 148,
		CODER_FORMAT_SPECIFIER_NONE            = 255
		
	} CoderFormatSpecifier;


	bool coder_explicit_format_byte_present(CoderFormatSpecifier fmtSpec);
	bool coder_is_result(CoderFormatByte fmtByte);
	uint8_t coder_command_size(CoderFormatByte fmtByte, uint8_t maxSize);
	uint8_t coder_result_size(CoderFormatSpecifier fmtSpec);
	bool coder_result_increments_expected_index(CoderFormatByte fmtByte);
	uint8_t coder_truncate_valid_rss(uint8_t rss);
	CoderFormatSpecifier coder_format_specifier(PostprocFormat fmt);
	CoderFormatByte coder_format_byte(
		CoderFormatSpecifier fmtSpec,
		uint8_t sheetIndex
	);
	PostprocFormat coder_postproc_format(CoderFormatSpecifier fmtSpec);
	CoderFormatSpecifier coder_format_specifier_from_byte(
		CoderFormatByte fmtByte
	);
	uint8_t coder_sheet_index_from_byte(CoderFormatByte fmtByte);
	uint32_t coder_index(uint8_t * indx);
	uint32_t coder_next_index(
		uint32_t currentIndex,
		CoderFormatByte fmtByte,
		uint8_t * cmd
	);

#endif

