/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Calculation of 32 bit CRC sums using a fixed generator polynomial. Further
  documentation may be found in the corresponding source file.
   
  Authors
  =======
  
    Copyright (C) 2018-2021  Gerrit Maus (funk@maus.xyz)
    Copyright (C) 2018-2018  Mustafa Gemci (mustafagemci.ee@gmail.com)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
   Changelog
   =========
  
    2018-09-25    Initial release.
    2019-04-15    Initial public release.
    2021-04-02    Added {crc_append_zeros()}.
*/


#include <stdint.h>
#include <stddef.h>
#include <stdbool.h>


void crc_reset(uint32_t * crc);
void crc_append(uint32_t * crc, uint8_t byte);
void crc_append_zeros(uint32_t * crc, size_t amount);
void crc_finish(uint32_t * crc);
bool crc_check(uint32_t crc);
uint32_t crc(uint8_t * byte, size_t size);

