/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  BLE 5.1 Constant Tone Extension (CTE) related informations. Further
  documentation may be found in the corresponding source file.
  
  Authors
  =======
  
    Copyright (C) 2020-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2020-08-24    Outsourced from the cte module.
    2021-03-05    Added {CTEINFO_MAX_HASH_VALUE} and {cteinfo_hash()}.
*/


#ifndef RSS2I_INCLUDE_GUARD_CTEINFO_H
#define RSS2I_INCLUDE_GUARD_CTEINFO_H
	
	#include <stdbool.h>
	#include <stdint.h>
	
	#include <rss2i/cte.h>
	
	#define CTEINFO_MAX_HASH_VALUE ((CTE_ANTENNA_PATTERN_ALWAYS_LAST_SWITCH \
	                               - CTE_ANTENNA_PATTERN_INVALID_SWITCH     \
	                               + CTE_ANTENNA_PATTERN_ALWAYS_LAST_CONST  \
	                               - CTE_ANTENNA_PATTERN_INVALID_CONST)     \
	                              * CTE_TYPE_ALWAYS_LAST_ITEM               \
	                              + CTE_TYPE_ALWAYS_LAST_ITEM)              
	
	
	bool cteinfo_type_is_valid(CTEType type);
	bool cteinfo_antenna_pattern_is_valid(uint8_t boardRev,
		                                  uint8_t boardType,
		                                  CTEAntennaPattern ant,
		                                  CTEType type);
	uint8_t cteinfo_num_of_antennas(uint8_t boardRev, uint8_t boardType);
	size_t cteinfo_hash(CTEType type, CTEAntennaPattern pat);
	
#endif

