/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Controls the onboard LEDs. Further documentation may be found in the
  corresponding source file.
  
  Authors
  =======
  
    Copyright (C) 2018-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2018-07-24    Initial release.
    2020-06-10    Check for incompatible timings between different revisions.
*/

#ifndef RSS2I_INCLUDE_GUARD_LED_H
#define RSS2I_INCLUDE_GUARD_LED_H


#include <rss2i/rev.h>

#include <rss2i/config/led.h>


typedef enum {
	
	LED_GREEN,
	LED_YELLOW,
	LED_RED,

} LED;

typedef enum {

	LED_OFF,
	LED_BLINK,
	LED_ON,
	
} LEDPattern;

void led_init(void);
void led_set(LED led, LEDPattern pattern);
void led_trigger(void);

#if REVISION >= 5
	
	#if LED_SLOT_PAUSE + LED_SLOT_OFFSET * 2 != (3 + PWM_SLOTS_BEFORE + PWM_SLOTS_AFTER) * PWM_SLOT_DURATION
		
		#error "The LED timing settings for rev. A to E and rev. F are incompatible."
	#endif
#endif

#endif /* RSS2I inlcude guard */

