/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  API for controlling the external flash memory. Further documentation may be
  found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2018-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2019-06-28    Initial public release.
    2019-10-31    Added {memory_ready_to_request()}.
    2020-07-13    Added {memory_*lock()} and {memory_measure_write_results()}.
    2021-04-01    Replace {*write_result()} by modified {*write_results()}.
    2021-04-29    Make it possible to finish a partially written flash page.
*/

#include <stdint.h>

#include <rss2i/coder.h>


typedef enum {
	
	MEMORY_TEST_ONGOING,
	MEMORY_TEST_SUCCEEDED,
	MEMORY_TEST_FAILED,
	
} MemoryTestStatus;


void memory_init(void);
void memory_finish(void);
void memory_reset(void);
bool memory_measure_write_results(
	
	uint32_t index,
	uint8_t rssIntegerPart,
	uint8_t rssFractionalPart,
	CoderFormatSpecifier fmtSpec,
	uint8_t * samples,
	uint8_t size,
	bool reset,
	bool finish
);

bool memory_ready_to_request(void);
bool memory_request_offset(uint32_t offset);
bool memory_request_absolute(uint32_t address);
bool memory_request_ready(void);
uint8_t * memory_read(void);

void memory_unlock(void);
void memory_lock(void);

uint8_t memory_get_load(void);
uint32_t memory_get_start_address(void);
uint32_t memory_get_page_count(void);

MemoryTestStatus memory_full_test(void);
MemoryTestStatus memory_fast_test(void);

