/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Measurement data post processing. Further documentation may be found in the
  corresponding source file.
  
  Authors
  =======
  
    Copyright (C) 2020-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2020-08-14    Initial release.
    2021-03-18    Added {radioMode} and {sampleType} args to {postprocess()}.
    2021-03-31    Added {frameCount} arg to {postprocess()}.
    2021-04-15    Added a return value and {storeSamples} to {postprocess()}.
    2021-04-16    Added {PostprocFormat}.
    2021-04-19    Renamed {postproc_cte_sample*()} to {postproc_sample*()}.
    2021-04-29    Support {CTE_2US_7PX1} {CTEType}.
*/

#ifndef RSS2I_INCLUDE_GUARD_POSTPROC_H
#define RSS2I_INCLUDE_GUARD_POSTPROC_H
	
	#include <stdint.h>
	
	#include <rss2i/cte.h>
	#include <rss2i/radio.h>
	#include <rss2i/measure.h>
	
	
	typedef enum {
		
		POSTPROC_FORMAT_INVALID = -1,
		POSTPROC_FORMAT_0,
		POSTPROC_FORMAT_1,
		
		POSTPROC_FORMAT_ALWAYS_LAST_ITEM
		
	} PostprocFormat;
	
	
	uint8_t postproc_sample_request(uint8_t frame);
	void postproc_sample_clear_request(void);
	uint8_t postproc_sample_status(void);
	
	uint8_t postproc_sample_sheet(uint8_t sheetIndex,
	                                  uint8_t * framePtr,
	                                  uint8_t * formatPtr,
	                                  uint8_t * sheet);
	
	bool postprocess(uint8_t frame,
	                 int32_t cycle,
	                 uint8_t frameCount,
	                 CTEType cteType,
	                 CTEAntennaPattern cteAntPat,
	                 uint8_t rssAvgIntegerPart,
	                 uint8_t rssAvgFractionalPart,
	                 uint8_t rssAmount,
	                 uint8_t sampleAmount,
	                 RadioMode radioMode,
	                 MeasureBufferSampleType sampleType,
	                 bool storeSamples,
	                 uint8_t * radioPacket);
	
#endif

