/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  API for enabling and disabling some predefined inter peripheral shortcuts.
  Further documentation may be found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2018-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2019-06-13    Initial release.
    2019-09-26    Add {PPI_TIMER2_COMPARE0_RADIO_RSSISTART}.
    2020-06-09    Use {TIMER1} instead of {TIMER3}.
    2020-08-07    Replaced {RADIO_DISABLED} by {RADIO_END}.
    2020-08-25    Added {PPI_RADIO_CRCOK_TIMER1_START}.
    2021-03-01    Added {PPI_RADIO_FRAMESTART_RADIO_RSSISTART}.
    2021-03-25    Added {PPI_*_GPIOTE_*_CHANNEL_DEBUG_PIN}.
    2021-03-25    Removed {PPI_RADIO_END_TIMER1_CLEAR}.
    2021-03-25    Changed order of PPI defines.
*/

#include <rss2i/rev.h>


/* A complete list of available inter peripheral shortcuts: */

typedef enum {
	
	PPI_RADIO_CRCOK_TIMER1_CLEAR,
	PPI_RADIO_CRCOK_TIMER1_START,
	PPI_TIMER2_COMPARE0_RADIO_RSSISTART,
#if REVISION >= REVISION_F
	PPI_RADIO_FRAMESTART_RADIO_RSSISTART,
#endif
	PPI_TIMER1_COMPARE0_GPIOTE_OUT_CHANNEL_DEBUG_PIN,
	PPI_TIMER1_COMPARE1_GPIOTE_SET_CHANNEL_DEBUG_PIN,
	PPI_RADIO_READY_GPIOTE_CLR_CHANNEL_DEBUG_PIN,
	
	PPI_TYPE_ALWAYS_LAST_ITEM

} PPIType;


void ppi_init(PPIType ppiType);
void ppi_enable(PPIType ppiType);
void ppi_disable(PPIType ppiType);

