/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Provide chip revision information.
  
  Authors
  =======
    
    Copyright (C) 2020-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2020-06-05    Initial release.
    2020-07-30    Added {rev_is_compatible_with()} and {ref()}.
    2020-07-31    Distinguish more clearly between board and chip revision.
    2020-08-04    Added {REVISION_*} macros.
    2020-09-10    Added {REVISION_H} macro.
    2021-02-12    Added {REVISION_I} macro.
*/

#ifndef RSS2I_INCLUDE_GUARD_REV_H
#define RSS2I_INCLUDE_GUARD_REV_H

	#include <stdbool.h>

	#include <rss2i/board.h>
	
	#include <rss2i/config/generated.board.h>

	/* The file "config/generated.rev.h" is auto-generated */
	/* at build time and has no include guard.             */
	#ifndef RSS2I_INCLUDE_GUARD_CONFIG_GENERATED_REV_H
	#define RSS2I_INCLUDE_GUARD_CONFIG_GENERATED_REV_H
		#include <rss2i/config/generated.rev.h>
	#endif
	
	
	#define REVISION_A 0
	#define REVISION_B 1
	#define REVISION_C 2
	#define REVISION_D 3
	#define REVISION_E 4
	#define REVISION_F 5
	#define REVISION_G 6
	#define REVISION_H 7
	#define REVISION_I 8
	
	
	#ifdef BOARD_REV
		
		_Static_assert(
			REVISION >= REVISION_F || BOARD_REV < BOARD_REV_F,
			"This chip revision cannot emulate the specified RSS2I board revision."
		);
		
	#endif
	
	
	BoardRev rev(void);
	bool rev_is_compatible_with(BoardRev rev);
	
#endif

