/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  SPIM module for SPI communication with multiple FLASH devices. Further
  documentation may be found in the corresponding source file.
  
  Authors
  =======
  
    Copyright (C) 2018-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2019-01-21    Initial release.
    2019-05-31    Added {spim_vacant_entries()}.
    2019-10-31    Removed {spim_recv_reset_blocking()}.
    2020-07-08    Added the DMA-based {spim_query_*()} querying procedures.
*/

#include <stdbool.h>
#include <stdint.h>
#include <stddef.h>


void spim_recv_reset_blocking(void);
bool spim_recv_ready(void);
uint8_t * spim_recv(void);
uint8_t * spim_query_request(void);
bool spim_query_finish(uint8_t * addr, size_t size);
bool spim_query(uint8_t * data, size_t size);
void spim_init(uint8_t * welQuery, size_t welSize, uint8_t * wipQuery, size_t wipSize, bool (* check_wip)(uint8_t *));
void spim_trigger(void);
size_t spim_vacant_entries(void);

