/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Control the external HF switch(es). Further documentation may be found in the
  corresponding source file.
  
  Authors
  =======
  
    Copyright (C) 2020-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2020-08-06    Initial release.
    2020-08-25    Added HF switch protection in brownout case.
    2021-03-29    Added {switch_get_standard_antenna()}.
*/

#ifndef RSS2I_INCLUDE_GUARD_SWITCH_H
#define RSS2I_INCLUDE_GUARD_SWITCH_H

	#include <stdint.h>
	
	
	typedef enum {
		
		SWITCH_ANTENNA_1,
		SWITCH_ANTENNA_2,
		SWITCH_ANTENNA_3,
		SWITCH_ANTENNA_4,
		SWITCH_ANTENNA_5,
		SWITCH_ANTENNA_6,
		SWITCH_ANTENNA_7,
		SWITCH_ANTENNA_8,
		
		SWITCH_ANTENNA_ALWAYS_LAST_ITEM
		
	} SwitchAntenna;
	
	
	void switch_init(void);
	uint8_t switch_get_number_of_used_pins(void);
	uint32_t switch_get_pin_number_of_bit(uint8_t bit);
	SwitchAntenna switch_get_standard_antenna(void);
	uint32_t switch_get_standard_pattern(void);
	uint32_t switch_get_pattern(SwitchAntenna ant);
	void switch_set(uint8_t pattern);
	void switch_lock(void);

#endif

