/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Provides some timers with a resolution of 1 ms. Further documentation may be
  found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2018-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2019-05-29    Initial public release.
    2019-06-25    Added {TimerID}.
    2020-06-09    Added {timer_reset()}.
*/

#include <stdint.h>
#include <stdbool.h>

#define TIMER_REPEAT true
#define TIMER_NO_REPEAT false

typedef uint32_t TimerID;

TimerID timer_call(void (* call)(), uint32_t ms, bool repeat);
bool timer_wait(uint32_t ms);
TimerID timer_flag(volatile bool * flag, uint32_t ms, bool repeat);
void timer_clear(TimerID token);
void timer_reset(TimerID token);
void timer_trigger(void);
void timer_init(void);
