/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Fast UART (up to 1 MBaud/s) with buffers for both communication directions.
  Further documentation may be found in the corresponding source file.
  
  Authors
  =======
    
    Copyright (C) 2018-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2019-04-15    Initial public release.
    2019-11-04    Introduced {UARTEBaudrate}. {uarte_set_baudrate_blocking()}
                  has been removed and replaced by {uarte_change_baudrate()}.
    2020-07-07    Added {uarte_send_*()} DMA-based procedures.
*/

#include <stdint.h>
#include <stdbool.h>
#include <stddef.h>


typedef enum {
	UARTE_BAUDRATE_115200,
	UARTE_BAUDRATE_230400,
	UARTE_BAUDRATE_250000,
	UARTE_BAUDRATE_460800,
	UARTE_BAUDRATE_921600,
	UARTE_BAUDRATE_1000000,
	
	UARTE_BAUDRATE_CHANGE_ONGOING,
	
} UARTEBaudrate;


UARTEBaudrate uarte_change_baudrate(UARTEBaudrate baudrate);
void uarte_init(UARTEBaudrate baudrate,
                uint8_t * firstRecvData1,
                uint8_t * firstRecvData2,
                uint8_t * secRecvData,
                size_t * secRecvSize,
                size_t secRecvLength,
                size_t secRecvWidth,
                uint8_t * sendData,
                size_t * sendSize,
                size_t sendLength,
                size_t sendWidth);
uint8_t uarte_vacant_entries(void);
uint8_t * uarte_send_request(void);
bool uarte_send_finish(uint8_t * addr, size_t size);
bool uarte_send_data(uint8_t * data, size_t size);
uint8_t * uarte_recv(void);

