/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Wrapper for the cteinfo module that is used by librss2i. This library gets
  shipped with the RSS2I python package.
  
  Authors
  =======
    
    Copyright (C) 2020-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
    
  Changelog
  =========
    
    2020-08-24    Initial release.
    2021-03-11    Include stddef.h.
*/

#include <stdint.h>
#include <stdbool.h>
#include <stddef.h>

#include <rss2i/cteinfo.h>


bool rss2i_cteinfo_type_is_valid(int type){
/*
  Whether the specified CTE {type} is valid.
*/
	
	return cteinfo_type_is_valid(type);
}

bool rss2i_cteinfo_antenna_pattern_is_valid(uint8_t boardRev,
                                            uint8_t boardType,
                                            int ant,
                                            int type){
/*
  Whether the specified CTE {ant}enna pattern is supported by an RSS2I device
  with the specified {boardRev}ision and {boardType} and the given CTE {type} is
  compatible with that choice.
*/
	
	return cteinfo_antenna_pattern_is_valid(
		boardRev,
		boardType,
		ant,
		type
	);
}

uint8_t rss2i_cteinfo_num_of_antennas(uint8_t boardRev, uint8_t boardType){
/*
  Returns the number of antennas that may be used to transmit/receive a BLE 5.1
  Constant Tone Extension (CTE) with an RSS2I device with the specified
  {boardRev}ision and {boardType}. Note, that BLE 5.0 devices will always return
  zero.
*/
	
	return cteinfo_num_of_antennas(boardRev, boardType);
}

