/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Wrapper for the debug module that is used by librss2i. This library gets
  shipped with the RSS2I python package.
  
  Authors
  =======
    
    Copyright (C) 2018-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
    
  Changelog
  =========
    
    2019-08-30    Initial release.
    2020-02-12    Add {timer_*()} dummy functions.
    2020-03-31    Change terminology {DebugSource} -> {DebugErrorCase}.
    2020-07-09    Add  {suart_send_*()} dummy functions.
    2020-08-24    Introduce {HOOK_UNSUED()} in order to prevent warnings.
    2021-04-01    Add {rss2i_debug_get_num_of_error_cases*()} functions.
*/

#include <stdint.h>
#include <stddef.h>
#include <stdbool.h>

#include <rss2i/debug.h>
#include <rss2i/led.h>
#include <rss2i/timer.h>
#include <rss2i/hook.h>

const char * rss2i_debug_get_message(int debugErrorCase){
	
	if(debugErrorCase < 0){
		
		return NULL;
	}
	else{
		
		return debug_get_message(debugErrorCase);
	}
}

unsigned long int rss2i_debug_get_num_of_error_cases(void){
	
	return debug_get_num_of_error_cases();
}

uint8_t rss2i_debug_get_num_of_error_cases_per_page(void){
	
	return DEBUG_MAX_ERROR_CASES_PER_PAGE;
}



void suart_init(uint32_t period, char * data, size_t * size, size_t length, size_t width){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	HOOK_UNUSED(period);
	HOOK_UNUSED(data);
	HOOK_UNUSED(size);
	HOOK_UNUSED(length);
	HOOK_UNUSED(width);
}

void timer_init(void){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	;
}

TimerID timer_flag(volatile bool * flag, uint32_t ms, bool repeat){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	TimerID timer = 0;
	
	HOOK_UNUSED(flag);
	HOOK_UNUSED(ms);
	HOOK_UNUSED(repeat);
	
	return timer;
}

bool suart_busy(void){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	return false;
}

void led_set(LED led, LEDPattern pattern){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	HOOK_UNUSED(led);
	HOOK_UNUSED(pattern);
}

void led_init(void){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/

	;
}

void print_uhex(uint32_t d, char * dest, size_t pos, size_t len){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	
	HOOK_UNUSED(d);
	HOOK_UNUSED(dest);
	HOOK_UNUSED(pos);
	HOOK_UNUSED(len);
}

bool suart_send(const char * string){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	HOOK_UNUSED(string);
	
	return false;
}

uint8_t * suart_send_request(void){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	return NULL;
}

bool suart_send_finish(uint8_t * addr, size_t size){
/*
  Dummy implementation because some older versions of mingw complain about
  undefinded (but actually unused) functions.
*/
	
	HOOK_UNUSED(addr);
	HOOK_UNUSED(size);
	
	return false;
}

