/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

#define RSS2I_MODULE "gpiote"

/*
  API for setting up some predefined GPIOTE channels.
  
  Authors
  =======
    
    Copyright (C) 2021-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
    
    2021-03-25    Initial release.
  
  Description
  ===========
    
    This is an abstraction layer for the GPIOTE peripheral that defines some
    GPIOTE channels. A complete list of available GPIOTE channels can be
    obtained from the corresponding header file.
    
    Each GPIOTE channel has to be initialized via the {gpiote_init()} function
    before it can be used.
*/

#include <libopencm3/nrf5/gpiote.h>

#include <rss2i/gpiote.h>
#include <rss2i/debug.h>


/* TODO: Move this check to assert module? */
_Static_assert(
	GPIOTE_CHANNEL_ALWAYS_LAST_ITEM <= 8,
	"Too many GPIOTE channles used."
);


static bool gpioteInitialized[GPIOTE_CHANNEL_ALWAYS_LAST_ITEM];


void gpiote_init(GPIOTEChannel gpioteChannel){
/*
  Initialize the specified GPIOTE channel. May be called multiple times even
  for the same channel.
*/
	
	if(gpioteChannel < GPIOTE_CHANNEL_ALWAYS_LAST_ITEM){
	
		if(!gpioteInitialized[gpioteChannel]){
			
			gpioteInitialized[gpioteChannel] = true;
			
			switch(gpioteChannel){
				
				case GPIOTE_CHANNEL_DEBUG_PIN:
					
					GPIOTE_CONFIG[GPIOTE_CHANNEL_DEBUG_PIN] =
						  GPIOTE_CONFIG_MODE_TASK
						| GPIOTE_CONFIG_PSEL_VAL(DEBUG_MEASUREMENT_FRAME_PIN)
						| GPIOTE_CONFIG_POLARITY_TOGGLE
						| GPIOTE_CONFIG_OUTINIT_LOW;
					
				break;
				default:
					
					debug_report(DEBUG_GPIOTE_OUT_OF_RANGE);
			}
		}
	}
	else{
		
		debug_report(DEBUG_GPIOTE_OUT_OF_RANGE);
	}
}

