/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

#define RSS2I_MODULE "rev"

/*
  Provide chip revision information.
  
  Authors
  =======
  
    Copyright (C) 2020-2020  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2020-07-30    Initial release.
*/

#include <stdbool.h>

#include <rss2i/rev.h>
#include <rss2i/board.h>


BoardRev rev(void){
/*
  Returns the revision the code was compiled for.
*/
	
	return REVISION;
}

bool rev_is_compatible_with(BoardRev rev){
/*
  Whether the specified {rev}ision is compatible with the compiled revision
  information, i.e. whether the compiled revision is capable of emulating an
  RSS2I board with the specified {rev}ision.
*/
	
	if(REVISION <= BOARD_REV_E && rev >= BOARD_REV_F){
		
		return false;
	}
	else{
		
		return true;
	}
}

