/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

#define RSS2I_MODULE "watchdog"

/*
  Watchdog API.
  
  Authors
  =======
  
    Copyright (C) 2018-2019  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This firmware is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This firmware is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this firmware. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2019-06-25    Initial public release.
  
  Description
  ===========

    The watchdog runs after initialization using {watchdog_init()}. Before
    a watchdog timeout occurs after approximately 1500 ms, it should get reset
    by a call to {watchdog_reset()}.
*/


#include <stdbool.h>

#include <libopencm3/nrf5/wdt.h>
#include <libopencm3/nrf5/power.h>

#include <rss2i/debug.h>


static bool watchdog_triggered(){
/*
  Indicates whether the last reset was caused by a watchdog timeout.
*/
	
	if(POWER_RESETREAS & POWER_RESETREAS_DOG_Detected){
		
		/* Clear reset reason. */
		POWER_RESETREAS = POWER_RESETREAS_DOG_Detected;
		
		return true;
	}
	else{
		
		return false;
	}
}

static void watchdog_start(){
	
	WDT_TASKS_START = 1;
}

void watchdog_init(){
/*
  Activates the watchdog with a timeout period of about 1500 ms. A possible
  watchdog timeout (which may have caused the last reset) gets reported to the 
  debug system automatically.
*/
	
	WDT_CRV = 49151;
	WDT_CONFIG = 0;
	WDT_RREN = WDT_RREN_RR0_Enabled;
	
	debug_init();
	watchdog_start();
	
	if(watchdog_triggered()){
		
		debug_report(DEBUG_WATCHDOG_TRIGGERED);
	}
}

void watchdog_reset(){
/*
  Resets the watchdog counter. This reset should get triggered repeatedly after
  at most 1500 ms.
*/
	
	WDT_RR[0] = WDT_RR_RR_Reload;
}

