/*
  This file is part of the RSS2I project licensed under the GNU GPL v3.0+
*/

/*
  Some helper routines for the unit tests.
   
  Authors
  =======
  
    Copyright (C) 2018-2021  Gerrit Maus (funk@maus.xyz)
    
  License
  =======
    
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
    Software Foundation, either version 3 of the License, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along with
    this program. If not, see <https://www.gnu.org/licenses/>.
  
  Changelog
  =========
  
    2021-04-02    Initial release.
*/

#include <stdio.h>
#include <stdbool.h>
#include <stdint.h>
#include <inttypes.h>


void test_ident(void){
	
	printf("              ");
}

void test_status(const char * string){
/*
  Prints the current status. Three dots "..." are appended automatically.
*/
	
	test_ident();
	printf("%s...     ", string);
	fflush(stdout);
}

void test_progress(int progress){
/*
  Prints the progress in percent. Should be preceeded by {test_status}.
*/
	
	if(progress < 0){ progress = 0; }
	if(progress > 100){ progress = 100; }
	
	printf("\b\b\b\b%03d%%", progress);
	fflush(stdout);
}

void test_ok(void){
/*
  Aborts the progress and displays "OK".
*/
	
	/* Trailing space in order to override the          */
	/* percent sign (%) of the status message (if any). */
	printf("\b\b\b\bOK. \n");
}

void test_failed(void){
/*
  Should be called prior to the first line of every error or debug message.
  Aborts the progress (if any).
*/
	
	static bool thrown = false;
	
	if(!thrown){
	
		printf("\b\b\b\bFailed.\n\n              -> ");
		thrown = true;
	}
	else{
	
		printf("              -> ");
	}
}

void test_newline(void){
/*
  Should be called of every further line of every error or debug message.
*/
	
	printf("\n                 ");
}

void test_stat_table_header(void){
/*
  Print quantity statistics table header.
*/
	
	printf("\n");
	test_ident();
	printf("+----------------------------------+----------------+\n");
	test_ident();
	printf("|             Quantity             |      Value     |\n");
	test_ident();
	printf("+----------------------------------+----------------+\n");
}

void test_stat_table_entry(const char * string, uint32_t val){
/*
  Print quantity statistics table entry.
*/
	
	test_ident();
	printf("| %-32s | %'14" PRIu32 " |\n", string, val);
	test_ident();
	printf("+----------------------------------+----------------+\n");
}

